@@ -41,12 +41,16 @@
 #' @section Function ID:
 #' 3-1
 
-gt_plt_winloss <- function(gt_object, column, max_wins = 17,
+gt_plt_winloss <- function(gt_object,
+                           column,
+                           max_wins = 17,
                            palette = c("#013369", "#D50A0A", "gray"),
-                           type = "pill", width = max_wins/0.83) {
-
+                           type = "pill",
+                           width = max_wins / 0.83) {
   stopifnot("'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in% class(gt_object))
-  stopifnot("type must be on of 'pill' or 'square'" = {type %in% c("pill", "square")})
+  stopifnot("type must be on of 'pill' or 'square'" = {
+    type %in% c("pill", "square")
+  })
   stopifnot("There must be 3 colors" = length(palette) == 3L)
 
   list_vals <- gt_index(gt_object = gt_object, {{ column }}, as_vector = TRUE)
@@ -54,10 +58,10 @@ gt_plt_winloss <- function(gt_object, column, max_wins = 17,
   stopifnot("The column must be a list-column" = is.list(list_vals))
   stopifnot("All values must be 1, 0 or 0.5" = unlist(list_vals) %in% c(NA, NULL, 1, 0, 0.5))
 
-  plot_fn_pill <- function(vals){
-
-    if(all(is.na(vals) | is.null(vals))){
-      plot_out <- ggplot() + theme_void()
+  plot_fn_pill <- function(vals) {
+    if (all(is.na(vals) | is.null(vals))) {
+      plot_out <- ggplot() +
+        theme_void()
     } else {
       input_data <- data.frame(
         x = 1:length(vals),
@@ -69,87 +73,107 @@ gt_plt_winloss <- function(gt_object, column, max_wins = 17,
 
       plot_out <- ggplot(input_data) +
         geom_segment(
-          aes(x = .data$x, xend = .data$xend, y = .data$y, yend = .data$yend, color = I(.data$color)),
-          size = 1, lineend = "round") +
+          aes(
+            x = .data$x,
+            xend = .data$xend,
+            y = .data$y,
+            yend = .data$yend,
+            color = I(.data$color)
+          ),
+          linewidth = 1,
+          lineend = "round"
+        ) +
         scale_x_continuous(limits = c(0.5, max_wins + 0.5)) +
         scale_y_continuous(limits = c(-.2, 1.2)) +
         theme_void()
-
-
     }
 
     out_name <- file.path(
       tempfile(pattern = "file", tmpdir = tempdir(), fileext = ".svg")
     )
 
-    ggsave(out_name, plot = plot_out,
-           dpi = 20, height = 3.81, width = width, units = "mm")
+    ggsave(
+      out_name,
+      plot = plot_out,
+      dpi = 20,
+      height = 3.81,
+      width = width,
+      units = "mm"
+    )
 
     img_plot <- out_name %>%
       readLines() %>%
       paste0(collapse = "") %>%
       gt::html()
 
-    on.exit(file.remove(out_name), add=TRUE)
+    on.exit(file.remove(out_name), add = TRUE)
 
     img_plot
-
   }
 
-  plot_fn_square <- function(vals){
-
-    if(all(is.na(vals) | is.null(vals))){
-      plot_out <- ggplot() + theme_void()
+  plot_fn_square <- function(vals) {
+    if (all(is.na(vals) | is.null(vals))) {
+      plot_out <- ggplot() +
+        theme_void()
     } else {
+      input_data <- data.frame(
+        x = 1:length(vals),
+        xend = 1:length(vals),
+        y = ifelse(vals == 0.5, 0.4, vals),
+        yend = ifelse(vals == 0, 0.6, ifelse(vals > 0.5, 0.4, 0.6)),
+        color = ifelse(vals == 0, palette[2], ifelse(vals == 1, palette[1], palette[3]))
+      )
 
-    input_data <- data.frame(
-      x = 1:length(vals),
-      xend = 1:length(vals),
-      y = ifelse(vals == 0.5, 0.4, vals),
-      yend = ifelse(vals == 0, 0.6, ifelse(vals > 0.5, 0.4, 0.6)),
-      color = ifelse(vals == 0, palette[2], ifelse(vals == 1, palette[1], palette[3]))
-    )
-
-    plot_out <- ggplot(input_data) +
-      geom_point(
-        aes(x = .data$x, y = .data$y, color = I(.data$color)),
-        size = 1, shape = 15) +
-      scale_x_continuous(limits = c(0.5, max_wins + 0.5)) +
-      scale_y_continuous(limits = c(-.2, 1.2)) +
-      theme_void()
-
+      plot_out <- ggplot(input_data) +
+        geom_point(
+          aes(
+            x = .data$x,
+            y = .data$y,
+            color = I(.data$color)
+          ),
+          size = 1,
+          shape = 15
+        ) +
+        scale_x_continuous(limits = c(0.5, max_wins + 0.5)) +
+        scale_y_continuous(limits = c(-.2, 1.2)) +
+        theme_void()
     }
 
     out_name <- file.path(
       tempfile(pattern = "file", tmpdir = tempdir(), fileext = ".svg")
     )
 
-    ggsave(out_name, plot = plot_out,
-           dpi = 20, height = 0.15, width = 0.9)
+    ggsave(
+      out_name,
+      plot = plot_out,
+      dpi = 20,
+      height = 0.15,
+      width = 0.9
+    )
 
     img_plot <- out_name %>%
       readLines() %>%
       paste0(collapse = "") %>%
       gt::html()
 
-    on.exit(file.remove(out_name), add=TRUE)
+    on.exit(file.remove(out_name), add = TRUE)
 
     img_plot
-
   }
 
 
   text_transform(
     gt_object,
     locations = cells_body(columns = {{ column }}),
-    fn = function(x){
+    fn = function(x) {
       lapply(
         list_vals,
-        if(type == "pill"){plot_fn_pill} else {plot_fn_square}
+        if (type == "pill") {
+          plot_fn_pill
+        } else {
+          plot_fn_square
+        }
       )
     }
   )
-
 }
-
-
